<?php
namespace ONLINE_ADAv4;

add_action("wp_ajax_oada__regenerate_sitemap", __NAMESPACE__ . "\\regenerate_sitemap");

function regenerate_sitemap()
{
    delete_option("_oadaas_sitemap");
    $sitemap = [];
    $pages = get_pages();
    $posts = get_posts();
    $merged = array_merge($pages, $posts);
    array_unshift($merged, home_url());
    $pattern = "/\.\w+$/"; //check for extensions.
    foreach ($merged as $object) {
        
        $link = $object;
        if( $object !== \home_url() ){
            $link = sanitize_text_field(trim(untrailingslashit(get_page_link($object->ID))));
            preg_match($pattern, $link, $match);
        }
        
        if(!empty($match) && ( strpos($match[0], ".php") === FALSE && strpos($match[0], ".html") === FALSE ) ){
            continue;
        }

        if (strpos($link, "?") !== false) {
            $sitemap["query_links"][] = $link;
        } else {
            $sitemap["non_query_links"][] = $link;
        }
    }

    $result = add_option("_oadaas_sitemap", $sitemap);
    echo $result ? json_encode(get_option("_oadaas_sitemap")) : false;
    wp_die();
}

add_action("wp_ajax_oada__save_sitemap", __NAMESPACE__ . "\\save_sitemap");
function save_sitemap()
{
    if (!isset($_POST["sitemap"]) || empty($_POST["sitemap"])) {
        echo "empty";
        exit;
    }
    $sitemap_pre = $_POST["sitemap"];
    $sitemap_final = [];
    
    $pattern = "/\.(\w+)$/"; //check for extensions.
    foreach ($sitemap_pre as $link) {
        $link = sanitize_text_field(trim(untrailingslashit($link)));
        if( $link !== home_url() ){
            preg_match($pattern, $link, $match);
        }
        
        if(!empty($match) && in_array($match[1], Helper::media_extensions())){
            continue;
        }
        
        if(strpos( $link, home_url() ) === false){
            continue;
        }

        if (strpos($link, "?") !== false) {
            $sitemap_final["query_links"][] = $link;
        } else {
            $sitemap_final["non_query_links"][] = $link;
        }
    }
    delete_option("_oadaas_sitemap");
    $re = add_option("_oadaas_sitemap", $sitemap_final);
    echo $re ? json_encode(get_option("_oadaas_sitemap")) : "failed";
    wp_die();
}

add_action("wp_ajax_oada__parse_upload", __NAMESPACE__ . "\\parse_upload");
function parse_upload()
{
    $re = server_validate_upload($_FILES["file"]);
    if ($re != "success") {
        echo $re;
        wp_die();
    }
    delete_option("_oadaas_sitemap");
    $sitemap_unfiltered = [];
    $path = wp_upload_dir()["basedir"] . "/oadaas/sitemap/sitemap.csv";
    if (is_file($path) && file_exists($path)) {
        $file = fopen($path, 'r');

        while (($line = fgetcsv($file, 0, "\n")) !== false) {
            $link = esc_html(wp_strip_all_tags($line[0], true));

            if (strpos($link, "?") !== false) {
                $sitemap_unfiltered["query_links"][] = sanitize_text_field(trim(untrailingslashit($link)));
            } else {
                $sitemap_unfiltered["non_query_links"][] = sanitize_text_field(trim(untrailingslashit($link)));
            }
        }

        fclose($file);
        unlink($path);

        $sitemap_final = filter_uploaded_sitemap($sitemap_unfiltered);
        $re = add_option("_oadaas_sitemap", $sitemap_final);
    }

    //Return the unfiltered array so the user can see feedback about why some links may not have been saved
    echo json_encode($sitemap_unfiltered);
    wp_die();
}

function filter_uploaded_sitemap($sitemap)
{
    $returnMe = [];
    foreach ($sitemap as $type => $links) {
        foreach ($links as $link) {
            if ((strpos($link, "http://") !== false && strpos($link, "http://") === 0) || (strpos($link, "https://") !== false && strpos($link, "https://") === 0) &&
                strpos($link, home_url()) !== false) {
                $returnMe[$type] = sanitize_text_field(trim(untrailingslashit($link)));
            }
        }
    }
    return $returnMe;
}

function server_validate_upload($file)
{
    $is_csv = true;
    $pathinfo = pathinfo($file['name']);

    if ($pathinfo["extension"] !== "csv") {
        $is_csv = false;
    }

    if (getimagesize($file["tmp_name"])) {
        return "Incorrect file format: " . $pathinfo["extension"];
        wp_die();
    }

    $supportedFormats = ['csv', 'txt', 'xml', 'xls', 'xlsx'];

    if (in_array($pathinfo["extension"], $supportedFormats)) {
        //Store the uploaded file to the server
        $basedir = wp_upload_dir()["basedir"];
        $rel_path = "/oadaas/sitemap/";

        $filename = "sitemap." . $pathinfo["extension"];
        $path = $basedir . $rel_path . $filename;

        if (!file_exists($basedir . $rel_path)) {
            mkdir($basedir . $rel_path, 0777, true);
        }

        $success = move_uploaded_file($file["tmp_name"], $path);

        if ($success && !$is_csv) {
            $new_filename = "sitemap.csv";
            //Convert the file to CSV
            switch ($pathinfo["extension"]) {
                case "xml":
                    if (file_exists($path)) {
                        $xml = simplexml_load_file($path);
                        $f = fopen($basedir . $rel_path . $new_filename, 'w');
                        convert_xml_to_csv($xml, $f);
                        $stat = fstat($f);
                        ftruncate($f, $stat['size'] - 1);
                        fclose($f);
                        unlink($path);
                    }
                    break;
            }
            return "success";
        }
        if ($is_csv) {
            $put_arr = [];
            if (file_exists($path)) {
                //Read and store contents of uploaded CSV file into an array
                $f = fopen($path, 'r');
                while (($line = fgetcsv($f, 0, ",")) !== false) {
                    $put_arr[] = $line;
                }
                fclose($f);

                //Rewrite the CSV file to use '/n' after delimiter
                $f = fopen($path, "w");
                foreach ($put_arr[0] as $item) {
                    fputcsv($f, [$item], ',', '"');
                }
                $stat = fstat($f);
                ftruncate($f, $stat['size'] - 1);
                fclose($f);
                return "success";
            }
        }
    }
    return "Incorrect file format: " . $pathinfo["extension"];
    wp_die();
}

function convert_xml_to_csv($xml, $f)
{
    foreach ($xml->children() as $item) {
        $hasChild = (count($item->children()) > 0) ? true : false;

        if (!$hasChild) {
            if ($item->getName() === "loc") {
                fputcsv($f, [$item], ',', '"');
            }
        } else {
            convert_xml_to_csv($item, $f);
        }
    }
}
