<?php
namespace ONLINE_ADAv4;

use ONLINE_ADAv4\Helper;

add_action('rest_api_init', __NAMESPACE__ .'\\csv_page_download');
function csv_page_download()
{
    register_rest_route('ada-plugin/v1', '/pagecsv', array(
        'methods' => 'GET',
        'callback' => __NAMESPACE__ . '\\page_csv'
    ));
}

function page_csv($request)
{
    //Go through this 5 pages at a time and save 5 pages at a time to the CSV. Open it then append another 5 pages...

    $offset = 0;
    $limit = 5;
    $total_rows = Helper::get_row_count($_GET["scan_id"]);
    $articles = Helper::getWcagArticlesModel(2);
    $guidelines = Helper::getWcagArticlesModel(1, true);
    $csv_path = wp_upload_dir()["basedir"] . "/oadaas/csv_reports/";
    $filename = $_GET["scan_id"]. "_csv_report";
    $fullPath = $csv_path . $filename;

    
    while($offset <= $total_rows){
        $all_issues = Helper::get_scan_data($_GET["scan_id"], $offset, $limit);
        $false_positives = Helper::get_false_positives($_GET["scan_id"]);
        if(empty($false_positives)){
            $false_positives = [];
        }

        if($offset === 0){
            //Create the CSV
            if(!file_exists($csv_path)){
                mkdir($csv_path, 0777, true);
            }
            
            $csv = fopen($fullPath, 'w');
            //Header row
            fputcsv($csv, ["Issue #", "Page", "Article #", "WCAG Level", "Description", "Source Code"]);
            
        }else{
            //Retrieve and append to
            $csv = fopen($fullPath, 'a');
        }

        $formatted = formatResults($all_issues, $false_positives);

        foreach ($formatted as $array) {
            fputcsv($csv, $array);
        }

        fclose($csv);

        $offset += $limit;
    }

    $title = strtolower($_GET["scan_title"]);
    $title = explode(" ", $title);
    $title = implode("_", $title);
    $title = explode("-", $title);
    $title = implode("_", $title);
    
    header('Content-Type: text/csv; charset=utf-8');
    header('Content-Disposition: attachment; filename=' . $title . "-report.csv");
    
    echo file_get_contents($fullPath);
    die;
}

function formatResults($scan_data, $false_positives){
    $formatted = [];
    $issue_number = 1;
    foreach ($scan_data AS $cat_title => $cat_items) {
        if($cat_title == "issues"){ continue; }

        foreach($cat_items AS $item){
            if(in_array($item["issueID"], $false_positives)){ continue; }
            $page = "Homepage";
            if(isset($item["page"])){
                $page = home_url()."/".$item["page"];
            }
            $articles = "best practice";
            
            if(!empty($item["articles"])){
                $articles = '"';
                foreach($item["articles"] AS $index => $art){
                    $articles .= $art;
                    $articles .= ', ';
                }
                $articles = rtrim($articles, ", ");
                $articles .= '"';
            }

            $types = "BP";
            
            if(!empty($item["types"])){
                $types = '"';
                $convert = [
                    "wcag level A" => "A",
                    "wcag level AA" => "AA",
                    "contrast"  => "AA"
                ];
                
                foreach($item["types"] AS $index => $type){
                    if(empty($convert[$type])){continue;}
                    $types .= $convert[$type];
                    $types .= ', ';
                    
                }
                $types = rtrim($types, ", ");
                $types .= '"';
            }

            $html = stripslashes($item["html"]);
            if(strlen(stripslashes($item["html"])) > 300){
                $html = substr(stripslashes($item["html"]), 0, 300) . " [... truncated]";
            }

            $message = $item["message"];
            if(empty($message)){
                $message = $item["issueData"]["any"][0]["message"];
            }
            
            $formatted[] = [ $issue_number, $page, $articles, $types, $message, $html ];
            $issue_number++;   
        }
    }

    return $formatted;
}